==> haskell-tasty-hedgehog-1.4.0.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hedgehog
version:              1.4.0.1
visibility:           public
id:                   tasty-hedgehog-1.4.0.1-CXEeR7jDICyK58x5RaiSEh
key:                  tasty-hedgehog-1.4.0.1-CXEeR7jDICyK58x5RaiSEh
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  cc7afc82ab83b6934b32c203c7fb3d23
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.1-CXEeR7jDICyK58x5RaiSEh
depends:
    base-4.17.2.1 hedgehog-1.2-YfHH2K3mxzIofshihIFIX
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.4.3-1VgnHOByr8AIto1CnZp8DF

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hedgehog-1.4.0.1-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hedgehog
version:              1.4.0.1
visibility:           public
id:                   tasty-hedgehog-1.4.0.1-L93u5YlnsC38xEv81NexQm
key:                  tasty-hedgehog-1.4.0.1-L93u5YlnsC38xEv81NexQm
license:              BSD-3-Clause
copyright:
    Copyright (c) 2017, Commonwealth Scientific and Industrial Research Organisation (CSIRO) ABN 41 687 119 230.

maintainer:           dave.laing.80@gmail.com
author:               Dave Laing
homepage:             https://github.com/qfpl/tasty-hedgehog
synopsis:             Integration for tasty and hedgehog.
description:
    Integrates the <https://hackage.haskell.org/package/hedgehog hedgehog testing library> with the <https://hackage.haskell.org/package/tasty tasty testing framework>.

category:             Testing
abi:                  42dfd95a4cb70913225c22e5276b1a65
exposed:              True
exposed-modules:      Test.Tasty.Hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hedgehog-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hedgehog
hs-libraries:         HStasty-hedgehog-1.4.0.1-L93u5YlnsC38xEv81NexQm
depends:
    base-4.17.2.1 hedgehog-1.2-BmYIP4kUp0nTN1S2q9CIp
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    tasty-1.4.3-1VgnHOByr8AIto1CnZp8DF

haddock-interfaces:
    /usr/share/doc/haskell-tasty-hedgehog/html/tasty-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-tasty-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
